A condensation rule is a formula that states how different attributes
combine to form an observed or latent response (Rupp, Templin, & Henson,
2010). The TDCM package includes support for "LCDM", "DINA",
"DINO", "CRUM", "RRUM", "LCDM1" for the LCDM with only main effects,
"LCDM2" for the LCDM with two-way interactions, "LCDM3", and so on.
Evaluate TDCM::tdcm.rules$TDCM for a complete list of condensation rules
supported by the TDCM package.